jobflow.core
============

jobflow.core.flow
-----------------

.. automodule:: jobflow.core.flow
   :members:
   :undoc-members:
   :show-inheritance:

jobflow.core.job
----------------

.. automodule:: jobflow.core.job
   :members:
   :show-inheritance:

jobflow.core.maker
------------------

.. automodule:: jobflow.core.maker
   :members:
   :undoc-members:
   :show-inheritance:

jobflow.core.reference
----------------------

.. automodule:: jobflow.core.reference
   :members:
   :undoc-members:
   :show-inheritance:
   :exclude-members: uuid, attributes, output_schema

jobflow.core.state
------------------

.. automodule:: jobflow.core.state
   :members:
   :undoc-members:
   :show-inheritance:

jobflow.core.store
------------------

.. automodule:: jobflow.core.store
   :members:
   :undoc-members:
   :show-inheritance:
